Coverage for manage.py: 0%

# Coverage for manage.py : 0%

## 3 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""

2 file: manage.py

3 description: allows using cli commands similar to Django.

4 Example all ``shopyo <cmd> [OPTIONS] [ARGS]...`` commands can also be run as

5``python manage.py <cmd> [OPTIONS] [ARGS]...``

6"""

7 from shopyo.api.cli import cli

8

9 if __name__ == "__main__":

10 cli()